==> apache-kylin-2.4.0-source-release.zip: apache-kylin-2.4.0/core-metadata/src/main/java/org/apache/kylin/metadata/datatype/BooleanSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.metadata.datatype;

import java.nio.ByteBuffer;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.BooleanUtils;

@SuppressWarnings("serial")
public class BooleanSerializer extends DataTypeSerializer<Long> {

    public final static String[] TRUE_VALUE_SET = { "true", "t", "on", "yes" };

    public BooleanSerializer(DataType type) {
    }

    @Override
    public void serialize(Long value, ByteBuffer out) {
        out.putLong(value);
    }

    @Override
    public Long deserialize(ByteBuffer in) {
        return in.getLong();
    }

    @Override
    public int peekLength(ByteBuffer in) {
        return 8;
    }

    @Override
    public int maxLength() {
        return 8;
    }

    @Override
    public int getStorageBytesEstimate() {
        return 8;
    }

    @Override
    public Long valueOf(String str) {
        if (str == null)
           return Long.valueOf(0L);
        else
            return Long.valueOf(BooleanUtils.toInteger(ArrayUtils.contains(TRUE_VALUE_SET, str.toLowerCase())));
    }
}

==> apache-kylin-4.0.4-source-release.zip: apache-kylin-4.0.4/core-metadata/src/main/java/org/apache/kylin/metadata/datatype/BooleanSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.metadata.datatype;

import java.nio.ByteBuffer;
import java.util.Locale;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.BooleanUtils;

@SuppressWarnings("serial")
public class BooleanSerializer extends DataTypeSerializer<Long> {

    public final static String[] TRUE_VALUE_SET = { "true", "t", "on", "yes" };

    public BooleanSerializer(DataType type) {
    }

    @Override
    public void serialize(Long value, ByteBuffer out) {
        out.putLong(value);
    }

    @Override
    public Long deserialize(ByteBuffer in) {
        return in.getLong();
    }

    @Override
    public int peekLength(ByteBuffer in) {
        return 8;
    }

    @Override
    public int maxLength() {
        return 8;
    }

    @Override
    public int getStorageBytesEstimate() {
        return 8;
    }

    @Override
    public Long valueOf(String str) {
        if (str == null)
            return Long.valueOf(0L);
        else
            return Long
                    .valueOf(BooleanUtils.toInteger(ArrayUtils.contains(TRUE_VALUE_SET, str.toLowerCase(Locale.ROOT))));
    }
}
